
X_SHIFT = 1
Y_SHIFT = 4
MAX_MOVES = 9
NUM_LINES = 3
NUM_COLUMNS = 3
GAME_TITLE = '************ TIC TAC TOE ************'
GAME_CONTROLS = 'Use arrows to move, [SPACE] Draw, [Q] Quit'
BOARD_GRID = '──┼───┼──'
MSG_QUIT = 'Press any key to quit'
